@@ -126,7 +126,7 @@ class HostedBackend(Backend):
         :param dataset_id: 数据集id
         :return: Class `Dataset` Object
         """
-        res = self._session.put(url=f'{self.api_address}/data/dataset/{dataset_id}',
+        res = self._session.put(url=f'{self.api_address}/{self.app_id}/data/dataset/{dataset_id}',
                                 json={"name": name, "zone": zone, "desc": desc})
         if res.json()['message']:
             raise Exception(res.json()['message'])
@@ -140,7 +140,7 @@ class HostedBackend(Backend):
         :param dataset_id:
         :return:
         """
-        res = self._session.delete(url=f'{self.api_address}/data/dataset/{dataset_id}')
+        res = self._session.delete(url=f'{self.api_address}/{self.app_id}/data/dataset/{dataset_id}')
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
@@ -156,7 +156,7 @@ class HostedBackend(Backend):
         :param desc:
         :return:
         """
-        res = self._session.put(url=f'{self.api_address}/training/model/{model_id}',
+        res = self._session.put(url=f'{self.api_address}/{self.app_id}/training/model/{model_id}',
                                 json={"app_id": app_id, "name": name, "desc": desc})
         if res.json()['message']:
             raise Exception(res.json()['message'])
@@ -170,7 +170,7 @@ class HostedBackend(Backend):
         :param model_id:
         :return:
         """
-        res = self._session.delete(url=f'{self.api_address}/training/model/{model_id}')
+        res = self._session.delete(url=f'{self.api_address}/{self.app_id}/training/model/{model_id}')
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
@@ -383,6 +383,8 @@ class HostedBackend(Backend):
         if res.json()["message"]:
             return None
         dict = res.json()['data']
+        self.set_app_id(dict['app_id'])
+
         return Dataset(self, dict['id'], dict['name'], dict['desc'], dict['zone'], dict['dimension'], dict['json_data'],
                        dict['create_time'], dict['type'], dict['create_user_id'], dict['update_time'],
                        dict['update_user_id'])
@@ -694,9 +696,9 @@ class HostedBackend(Backend):
         :path 文件路径
         :return: 返回文件，图片数据集文件，文件夹列表
         """
-        res = self._session.get(url=f'{self.api_address}/data/dataset/dir/{dataset_id}?path={path}')
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/dataset/dir/{dataset_id}?path={path}')
         if not path:
-            res = self._session.get(url=f'{self.api_address}/data/dataset/dir/{dataset_id}')
+            res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/dataset/dir/{dataset_id}')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         for d in res.json()['data']:
@@ -720,7 +722,7 @@ class HostedBackend(Backend):
         :param dataset_id:
         :return: 返回文件，图片数据集文件列表
         """
-        res = self._session.get(url=f'{self.api_address}/data/dataset/{dataset_id}/asset?page=-1')
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/dataset/{dataset_id}/asset?page=-1')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         artifacts = []
@@ -737,7 +739,8 @@ class HostedBackend(Backend):
         :param destination
         :return true or false
         """
-        res = self._session.get(url=f'{self.api_address}/data/dataset/filedownload/device/{dataset_id}/all')
+        res = self._session.get(
+            url=f'{self.api_address}/{self.app_id}/data/dataset/filedownload/device/{dataset_id}/all')
         try:
             destination_loc = os.path.join(destination, f'{name}.csv')
             content_size = len(res.content)
@@ -764,12 +767,12 @@ class HostedBackend(Backend):
         :param http_url: http地址 默认空
         :return: List of Class `Model` Object
         """
-        res = self._session.post(url=f'{self.api_address}/training/model/', json={"name": name,
-                                                                                  "app_id": app_id,
-                                                                                  "desc": desc,
-                                                                                  "auth_id": auth_id,
-                                                                                  "git_url": git_url,
-                                                                                  "http_url": http_url})
+        res = self._session.post(url=f'{self.api_address}/{app_id}/training/model/', json={"name": name,
+                                                                                           "app_id": app_id,
+                                                                                           "desc": desc,
+                                                                                           "auth_id": auth_id,
+                                                                                           "git_url": git_url,
+                                                                                           "http_url": http_url})
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
@@ -784,7 +787,7 @@ class HostedBackend(Backend):
         :param model_id:
         :return: Model instance
         """
-        res = self._session.get(url=f'{self.api_address}/training/model/{model_id}/')
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/training/model/{model_id}/')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         dict = res.json()['data']
@@ -1050,7 +1053,7 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     def get_repo_by_repo_id(self, repo_id):
-        res = self._session.get(url=f'{self.api_address}/training/model-repo/{repo_id}/')
+        res = self._session.get(url=f'{self.api_address}/{self.model_id}/training/model-repo/{repo_id}/')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         data = res.json()['data']
@@ -1061,7 +1064,7 @@ class HostedBackend(Backend):
     def _get_feature_zip_path(self, feature_id, imgtype):
         if imgtype == None:
             imgtype = ''
-        res = self._session.get(url=f'{self.api_address}/data/feature/{feature_id}/asset?type={imgtype}')
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/feature/{feature_id}/asset?type={imgtype}')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         data = res.json()['data']
@@ -1112,7 +1115,8 @@ class HostedBackend(Backend):
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
-
+        self.app_id = data['model']['app_id']
+        self.model_id = data['model_id']
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], param_json=data['param_json'],
                           host_id=data['host_id'], model_id=data['model_id'], dataset_id=data['dataset_id'],
                           start_time=data['start_time'], end_time=data['end_time'], state=data['state'],
@@ -1203,7 +1207,7 @@ class HostedBackend(Backend):
                     artifact_location=artifact_location,
                     online_train=False
                     )
-        res = self._session.post(url=f'{self.api_address}/training/experiment/', json=data)
+        res = self._session.post(url=f'{self.api_address}/{model_id}/training/experiment/', json=data)
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
@@ -1237,11 +1241,12 @@ class HostedBackend(Backend):
         :param experiment_id:
         :return:
         """
-        res = self._session.get(f'{self.api_address}/training/experiment/mlflow/{experiment_id}')
+        res = self._session.get(f'{self.api_address}/{self.app_id}/training/experiment/mlflow/{experiment_id}')
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
-
+        self.set_model_id(data['model_id'])
+        self.set_app_id(data['model']['app_id'])
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], host_id=data['host_id'],
                           param_json=data['param_json'],
                           model_id=data['model_id'], dataset_id=data['dataset_id'], start_time=data['start_time'],
@@ -1256,11 +1261,12 @@ class HostedBackend(Backend):
         :param run_id:
         :return:
         """
-        res = self._session.get(f'{self.api_address}/training/experiment/mlflow/run/{run_id}')
+        res = self._session.get(f'{self.api_address}/{self.app_id}/training/experiment/mlflow/run/{run_id}')
         if res.json()['message']:
             raise Exception(res.json()['message'])
         data = res.json()['data']
-
+        self.set_model_id(data['model_id'])
+        self.set_app_id(data['model']['app_id'])
         return Experiment(self, id=data['id'], name=data['name'], desc=data['desc'], host_id=data['host_id'],
                           param_json=data['param_json'],
                           model_id=data['model_id'], dataset_id=data['dataset_id'], start_time=data['start_time'],
@@ -1509,7 +1515,7 @@ class HostedBackend(Backend):
 
     @with_api_exceptions_handler
     def get_feature(self, feature_id):
-        res = self._session.get(url=f'{self.api_address}/data/feature/{feature_id}/')
+        res = self._session.get(url=f'{self.api_address}/{self.app_id}/data/feature/{feature_id}/')
         if res.json()["message"]:
             return None
         dict = res.json()['data']['data']
