@@ -12,12 +12,9 @@
 import logging
 import yaml
 import os
-
+from waveletai.utils import set_mlflow_tracing_waveletai_store
 from waveletai.constants import ModelRegisterMode
-from waveletai.exceptions import InvalidMLProjectFile
-from waveletai.utils import gen_id
 import mlflow
-from waveletai.experiment import Experiment
 
 _logger = logging.getLogger(__name__)
 
@@ -129,6 +126,7 @@ class Model(object):
 
         return self._backend.get_mlproject_file(self.id)
 
+    @set_mlflow_tracing_waveletai_store
     def create_experiment(self, name, params=None):
         """
         创建一个实验, 先创建mlflow的experiment, 再创建wai平台的experiment
@@ -142,6 +140,7 @@ class Model(object):
                                                is_train=True
                                                )
 
+    @set_mlflow_tracing_waveletai_store
     def get_experiment(self, experiment_id):
         """
         获取实验对象
